# Generated by Django 6.0.2 on 2026-02-09 12:53

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_email_learning",
            "0006_alter_apikey_salt_alter_imapconnection_salt_and_more",
        ),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="f90a341bca184781820f5ff8012bf350",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="f90a341bca184781820f5ff8012bf350",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterUniqueTogether(
            name="organizationuser",
            unique_together={("user", "organization")},
        ),
    ]



# Generated by Django 6.0.2 on 2026-02-13 08:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_email_learning",
            "0008_alter_apikey_salt_alter_imapconnection_salt_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="deliveryschedule",
            name="delivered_at",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="ff58446e143a4d69b7773604efeb581c",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="ff58446e143a4d69b7773604efeb581c",
                editable=False,
                max_length=32,
            ),
        ),
    ]



# Generated by Django 6.0.1 on 2026-01-29 07:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0003_apikey_salt_imapconnection_salt"),
    ]

    operations = [
        migrations.CreateModel(
            name="JobExecution",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "job_name",
                    models.CharField(
                        choices=[("DELIVER_CONTENTS", "deliver_contents")],
                        max_length=200,
                    ),
                ),
                ("started_at", models.DateTimeField(auto_now_add=True)),
                ("finished_at", models.DateTimeField(blank=True, null=True)),
                (
                    "status",
                    models.CharField(
                        choices=[("RUNNING", "running"), ("COMPLETED", "completed")],
                        max_length=50,
                    ),
                ),
            ],
        ),
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="727829a83ebd47f8baf0c15400d16119",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="727829a83ebd47f8baf0c15400d16119",
                editable=False,
                max_length=32,
            ),
        ),
    ]



# Generated by Django 6.0.1 on 2026-01-28 10:45

import django.core.validators
import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0001_initial"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="ApiKey",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "key",
                    models.CharField(
                        max_length=256,
                        unique=True,
                        validators=[django.core.validators.MinLengthValidator(50)],
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                (
                    "created_by",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
    ]



# Generated by Django 6.0.2 on 2026-02-13 07:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_email_learning",
            "0007_alter_apikey_salt_alter_imapconnection_salt_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="24cbbf453c064d1c99017f78d01115a1",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="24cbbf453c064d1c99017f78d01115a1",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.CreateModel(
            name="Certificate",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("issued_at", models.DateTimeField(auto_now_add=True)),
                ("name_on_certificate", models.CharField(max_length=200)),
                ("random_suffix", models.IntegerField()),
                (
                    "enrollment",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="certificate",
                        to="django_email_learning.enrollment",
                    ),
                ),
            ],
        ),
    ]



# Generated by Django 6.0.1 on 2026-01-30 10:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0004_jobexecution_alter_apikey_salt_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="course",
            name="image",
            field=models.ImageField(blank=True, null=True, upload_to="course_images/"),
        ),
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="847bdf99eb494499a2dce4f279456bcd",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="847bdf99eb494499a2dce4f279456bcd",
                editable=False,
                max_length=32,
            ),
        ),
    ]



from pydantic import BaseModel, Field
from django_email_learning.services.command_models.enroll_command import EnrollCommand
from django_email_learning.services.command_models.unsubscribe_command import (
    UnsubscribeCommand,
)


class CommandRequest(BaseModel):
    command: EnrollCommand | UnsubscribeCommand = Field(
        ..., discriminator="command_name"
    )



# Generated by Django 6.0.1 on 2026-02-02 08:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0005_course_image_alter_apikey_salt_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="9a60f001297443b3b6ac8d6cc7754ca6",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="9a60f001297443b3b6ac8d6cc7754ca6",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="learner",
            name="email",
            field=models.EmailField(max_length=254),
        ),
        migrations.AlterUniqueTogether(
            name="learner",
            unique_together={("organization", "email")},
        ),
    ]



# Generated by Django 6.0.1 on 2026-01-29 07:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0002_apikey"),
    ]

    operations = [
        migrations.AddField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="3e9a5a435c004a3e9a17417f21df4cdd",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AddField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="3e9a5a435c004a3e9a17417f21df4cdd",
                editable=False,
                max_length=32,
            ),
        ),
    ]
